nxtomomill provide a set of applications to convert tomography acquisition made from bliss (@ESRF) from their original file format (.edf, .h5) to a Nexus compliant file format (using [NXtomo](<https://manual.nexusformat.org/classes/applications/NXtomo.html))
